@@ -4,12 +4,17 @@
 
 import re
 import logging
+from bs4 import BeautifulSoup
 
 from .html import html_minify
 
 logger = logging.getLogger(__name__)
 
 
+def html_beautify(raw, settings):
+    return BeautifulSoup(raw, "html.parser").prettify(), None
+
+
 class Handler:
     """HTML handler class"""
 
@@ -31,8 +36,7 @@ class Handler:
     def process(self, raw: str, name: str = None):
         mode = self.settings.get("mode")
         if "beautify" == mode:
-            # TODO: Implement
-            return raw, None
+            return html_beautify(raw, self.settings)
         elif "minify" == mode:
             return html_minify(raw, self.settings)
         else:
