@@ -22,16 +22,19 @@ class Handler:
     def __init__(self, settings: dict):
         self.settings = settings
 
+    @classmethod
     def is_binary(self):
         return False
 
+    @classmethod
     def extensions(self):
         return ["jinja", "jinja2", "j2"]
 
+    @classmethod
     def name(self):
         return "jinja"
 
-    def process(self, raw: str):
+    def process(self, raw: str, name: str = None):
         mode = self.settings.get("mode")
         if "beautify" == mode:
             # TODO: Implement
