@@ -74,6 +74,7 @@ def parse_arguments(defaults):
     _option_group_general.add_argument("--overwrite", action="store_true", help="Allow overwrite files in-place. Default is skip and warn. NOTE: output fils are always overwritten. (Dangerous!!)", default=defaults.get("overwrite"))
     _option_group_general.add_argument("--on-change", action="store_true", help="Allow overwrite files only on source changed (detected by modify time).", default=defaults.get("on_change"))
     _option_group_general.add_argument("--verbose", action="store_true", help="Show output during processing.", default=defaults.get("verbose"))
+    _option_group_general.add_argument("--dry-run", action="store_true", help="Never touch files, only log what would have been done (for debugging purposes)", default=defaults.get("dry_run"))
     _option_group_general.add_argument("--force", action="store_true", help="Overwrite even if destination exists and is newer.", default=defaults.get("force"))
     _option_group_general.add_argument("--nproc", action="store", type=int, dest="nproc", default=nproc, metavar="NUM", help=f"Set number of cores for multiprocessing (default is number of cores available which is {nproc} on this machine)")
     _option_group_general.add_argument("--gzip", action="store_true", help="GZIP Processed files as '*.gz'.", default=defaults.get("gzip"))
@@ -151,6 +152,7 @@ def main():
             , "overwrite": False
             , "on_change": True
             , "verbose": False
+            , "dry_run": False
             , "force": False
             , "nproc": nproc
             , "gzip": False
@@ -168,6 +170,8 @@ def main():
         if verbose:
             logger.info(f"web-minifier version {__version__} started")
 
+        mode = settings.get("mode", "minify")
+        settings["mode"] = mode.value if type(settings["mode"]) is Mode else mode
         processor = Processor(settings)
         res, msg = processor.sanity_checks()
         if not res:
@@ -175,7 +179,6 @@ def main():
             sys.exit(1)
         if verbose:
             logger.info("Sanity check passed!")
-        logger.info(f"main.NPROC: {nproc}")
         status, msg = processor.process_files()
         if not status:
             logger.error(f"Processing failed with '{msg}', quitting...")
