@@ -38,6 +38,7 @@ class Processor:
         self.hash: bool = settings.get("hash", False)
         self.verbose: bool = settings.get("verbose", False)
         self.force: bool = settings.get("force", False)
+        self.dry_run: bool = settings.get("dry_run", False)
         self.nproc: int = settings.get("nproc", 1)
 
         self.handlers = HandlerManager()
@@ -138,28 +139,32 @@ class Processor:
         if None == processed_content:
             logger.warning(f"Processed file '{input_path}' was empty")
         try:
-            with open(output_path, "wb") if is_binary else open(output_path, "w", encoding="utf-8") as file:
-                written = file.write(processed_content)
-                if written != len(processed_content):
-                    return False, False, False, [f"Partially written output ({written} of {len(processed_content)} bytes)"]
+            if not self.dry_run:
+                with open(output_path, "wb") if is_binary else open(output_path, "w", encoding="utf-8") as file:
+                    written = file.write(processed_content)
+                    if written != len(processed_content):
+                        return False, False, False, [f"Partially written output ({written} of {len(processed_content)} bytes)"]
         except Exception as err:
             return False, False, False, [f"Could not write data to output file: {err}"]
         try:
-            os.utime(output_path, (input_mtime, input_mtime))
+            if not self.dry_run:
+                os.utime(output_path, (input_mtime, input_mtime))
         except Exception as err:
             return False, False, False, [f"Could not modify date of output file: {err}"]
         if self.gzip:
             try:
                 gzip_path = f"{output_path}{gzip_suffix}"
-                with open(gzip_path, "wb") as gzip_file:
-                    gzip_content = zlib.compress(processed_content, level=9)
-                    gzip_written = gzip_file.write(gzip_content)
-                    if gzip_written != len(gzip_content):
-                        return False, False, False, [f"Partially written gzip output ({gzip_written} of {len(gzip_content)} bytes)"]
+                if not self.dry_run:
+                    with open(gzip_path, "wb") as gzip_file:
+                        gzip_content = zlib.compress(processed_content, level=9)
+                        gzip_written = gzip_file.write(gzip_content)
+                        if gzip_written != len(gzip_content):
+                            return False, False, False, [f"Partially written gzip output ({gzip_written} of {len(gzip_content)} bytes)"]
             except Exception as err:
                 return False, False, False, [f"Could not write gzip data to output file: {err}"]
             try:
-                os.utime(gzip_content, (input_mtime, input_mtime))
+                if not self.dry_run:
+                    os.utime(gzip_content, (input_mtime, input_mtime))
             except Exception as err:
                 return False, False, False, [f"Could not modify date of gzip file: {err}"]
         # All went well, go home happy!
@@ -191,6 +196,8 @@ class Processor:
         skipped_count = 0
         messages = {}
         results = []
+        if self.dry_run:
+            logger.info(f"Dry run enabled, changes will NOT be commited to filesystem")
         if self.nproc > 1:
             logger.info(f"Doing multiprocessing with {self.nproc} cores")
             with Pool(self.nproc) as pool:
